@@ -10,7 +10,8 @@ package Devel::Cover::Report::Html_basic;
 use strict;
 use warnings;
 
-our $VERSION = '0.84'; # VERSION
+our $VERSION = '0.85'; # VERSION
+our $LVERSION = do { eval '$VERSION' || "0.001" };  # for development purposes
 
 use Devel::Cover::DB;
 use Devel::Cover::Web "write_file";
@@ -38,15 +39,17 @@ sub oclass
     $o ? class($o->percentage, $o->error, $criterion) : ""
 }
 
+my $threshold = { c0 => 75, c1 => 90, c2 => 100 };
+
 sub class
 {
     my ($pc, $err, $criterion) = @_;
     return "" if $criterion eq "time";
     no warnings "uninitialized";
     !$err ? "c3"
-          : $pc <  75 ? "c0"
-          : $pc <  90 ? "c1"
-          : $pc < 100 ? "c2"
+          : $pc < $threshold->{c0} ? "c0"
+          : $pc < $threshold->{c1} ? "c1"
+          : $pc < $threshold->{c2} ? "c2"
           : "c3"
 }
 
@@ -376,6 +379,8 @@ sub get_options
 {
     my ($self, $opt) = @_;
     $opt->{option}{outputfile} = "coverage.html";
+    $threshold->{$_} = $opt->{"report_$_"} for
+        grep { defined $opt->{"report_$_"} } qw( c0 c1 c2 );
     die "Invalid command line options" unless
         GetOptions($opt->{option},
                    qw(
@@ -405,6 +410,7 @@ sub report
                     $year + 1900, $mon + 1, $mday, $hour, $min, $sec
         },
         options => $options,
+        version => $LVERSION,
         showing => [ grep $options->{show}{$_}, $db->criteria ],
         headers =>
         [
@@ -439,7 +445,7 @@ sub report
         print_subroutines if $show->{subroutine} || $show->{pod};
     }
 
-    print "HTML output sent to $html\n";
+    print "HTML output written to $html\n" unless $options->{silent};
 }
 
 1;
@@ -449,7 +455,7 @@ package Devel::Cover::Report::Html_basic::Template::Provider;
 use strict;
 use warnings;
 
-our $VERSION = '0.84'; # VERSION
+our $VERSION = '0.85'; # VERSION
 
 use base "Template::Provider";
 
@@ -469,7 +475,7 @@ $Templates{html} = <<'EOT';
      "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
 <html xmlns="http://www.w3.org/1999/xhtml">
 <!--
-This file was generated by Devel::Cover Version $VERSION
+This file was generated by Devel::Cover Version [% version %]
 Devel::Cover is copyright 2001-2011, Paul Johnson (pjcj@cpan.org)
 Devel::Cover is free. It is licensed under the same terms as Perl itself.
 The latest version of Devel::Cover should be available from my homepage:
@@ -534,6 +540,22 @@ $Templates{summary} = <<'EOT';
         <td class="sh" align="right">Report date:</td>
         <td class="sv" align="left">[% R.date %]</td>
     </tr>
+    <tr>
+        <td class="sh" align="right">C0:</td>
+        <td class="sv c0" align="left">&lt;&nbsp;[% R.options.report_c0 %]%</td>
+    </tr>
+    <tr>
+        <td class="sh" align="right">C1:</td>
+        <td class="sv c1" align="left">&lt;&nbsp;[% R.options.report_c1 %]%</td>
+    </tr>
+    <tr>
+        <td class="sh" align="right">C2:</td>
+        <td class="sv c2" align="left">&lt;&nbsp;[% R.options.report_c2 %]%</td>
+    </tr>
+    <tr>
+        <td class="sh" align="right">C3:</td>
+        <td class="sv c3" align="left">&gt;=&nbsp;[% R.options.report_c2 %]%</td>
+    </tr>
 </table>
 <div><br></br></div>
 <table class="sortable" id="coverage_table">
@@ -748,7 +770,7 @@ s/^\s+//gm for values %Templates;
 
 =head1 VERSION
 
-version 0.84
+version 0.85
 Devel::Cover::Report::Html_basic - Backend for HTML reporting of coverage
 statistics
 
