@@ -7,7 +7,8 @@ use Getopt::Long;
 use Devel::Cover::DB;
 use Devel::Cover::Truth_Table;
 
-our $VERSION = '0.84'; # VERSION
+our $VERSION = '0.85'; # VERSION
+our $LVERSION = do { eval '$VERSION' || "0.001" };  # for development purposes
 
 #-------------------------------------------------------------------------------
 # Subroutine : get_coverage_for_line
@@ -150,6 +151,7 @@ sub merge_lineops {
 #===============================================================================
 my %Filenames;
 my @class = qw'c0 c1 c2 c3';
+my $threshold = { c0 => 75, c1 => 90, c2 => 100 };
 
 #-------------------------------------------------------------------------------
 # Subroutine : bclass()
@@ -169,9 +171,9 @@ sub bclass {
 sub pclass {
     my ($p, $e) = @_;
     return $class[3] unless $e;
-    $p <  75 && return $class[0];
-    $p <  90 && return $class[1];
-    $p < 100 && return $class[2];
+    $p < $threshold->{c0} && return $class[0];
+    $p < $threshold->{c1} && return $class[1];
+    $p < $threshold->{c2} && return $class[2];
     $class[3]
 }
 
@@ -261,7 +263,7 @@ sub print_html_header {
      "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
 <html xmlns="http://www.w3.org/1999/xhtml">
 <!--
-This file was generated by Devel::Cover Version $VERSION
+This file was generated by Devel::Cover Version $LVERSION
 Devel::Cover is copyright 2001-2011, Paul Johnson (pjcj\@cpan.org)
 Devel::Cover is free. It is licensed under the same terms as Perl itself.
 The latest version of Devel::Cover should be available from my homepage:
@@ -351,8 +353,6 @@ sub print_summary_report {
 
     my $outfile = "$options->{outputdir}/$options->{option}{outputfile}";
 
-    print "Writing HTML output to $outfile ...\n" unless $options->{silent};
-
     open(my $fh, '>', $outfile)
         or warn("Unable to open file '$outfile' [$!]\n"), return;
 
@@ -364,7 +364,21 @@ sub print_summary_report {
 <body>
 <h1>$options->{option}{summarytitle}</h1>
 <table>
-<tr><td class="h" align="right">Database:</td><td align="left">$db->{db}</td></tr>
+  <tr>
+    <td class="h" align="right">Database:</td><td align="left">$db->{db}</td>
+  </tr>
+  <tr>
+    <td class="h" align="right">C0:</td><td class="c0" align="left">&lt;&nbsp;$options->{report_c0}\%</td>
+  </tr>
+  <tr>
+    <td class="h" align="right">C1:</td><td class="c1" align="left">&lt;&nbsp;$options->{report_c1}\%</td>
+  </tr>
+  <tr>
+    <td class="h" align="right">C2:</td><td class="c2" align="left">&lt;&nbsp;$options->{report_c2}\%</td>
+  </tr>
+  <tr>
+    <td class="h" align="right">C3:</td><td class="c3" align="left">&gt;=&nbsp;$options->{report_c2}\%</td>
+  </tr>
 </table>
 <div><br/></div>
 <table>
@@ -412,6 +426,9 @@ END_HTML
     }
     print $fh "</table>\n</body>\n</html>\n";
     close($fh) or warn "Unable to close '$outfile' [$!]";
+
+    print "HTML output written to $outfile\n" unless $options->{silent};
+
 }
 
 
@@ -674,6 +691,8 @@ sub get_options
     $opt->{option}{pod}          = 1;
     $opt->{option}{outputfile}   = "coverage.html";
     $opt->{option}{summarytitle} = "Coverage Summary";
+    $threshold->{$_} = $opt->{"report_$_"} for
+        grep { defined $opt->{"report_$_"} } qw( c0 c1 c2 );
     die "Invalid command line options" unless
         GetOptions($opt->{option},
                    qw(
@@ -682,6 +701,9 @@ sub get_options
                        pod!
                        summarytitle=s
                        unified!
+                       report_c0=s
+                       report_c1=s
+                       report_c2=s
                      ));
 }
 
@@ -718,7 +740,7 @@ sub report {
 
 =head1 VERSION
 
-version 0.84
+version 0.85
 Devel::Cover::Report::Html_minimal - Backend for HTML reporting of coverage
 statistics
 
